url_teams = [
    "arizona-cardinals",
    "atlanta-falcons",
    "baltimore-ravens",
    "buffalo-bills",
    "carolina-panthers",
    "chicago-bears",
    "cincinnati-bengals",
    "cleveland-browns",
    "dallas-cowboys",
    "denver-broncos",
    "detroit-lions",
    "green-bay-packers",
    "houston-texans",
    "indianapolis-colts",
    "jacksonville-jaguars",
    "kansas-city-chiefs",
    "las-vegas-raiders",
    "los-angeles-rams",
    "los-angeles-chargers",
    "miami-dolphins",
    "minnesota-vikings",
    "new-england-patriots",
    "new-orleans-saints",
    "new-york-giants",
    "new-york-jets",
    "philadelphia-eagles",
    "pittsburgh-steelers",
    "san-francisco-49ers",
    "seattle-seahawks",
    "tampa-bay-buccaneers",
    "tennessee-titans",
    "washington-commanders",
]

encoded_teams = {
    "Arizona Cardinals": "AC",
    "Atlanta Falcons": "AF",
    "Baltimore Ravens": "BR",
    "Buffalo Bills": "BB",
    "Carolina Panthers": "CP",
    "Chicago Bears": "CHB",
    "Cincinnati Bengals": "CNB",
    "Cleveland Browns": "CLB",
    "Dallas Cowboys": "DC",
    "Denver Broncos": "DB",
    "Detroit Lions": "DL",
    "Green Bay Packers": "GBP",
    "Houston Texans": "HT",
    "Indianapolis Colts": "IC",
    "Jacksonville Jaguars": "JJ",
    "Kansas City Chiefs": "KC",
    "Las Vegas Raiders": "LVR",
    "Los Angeles Rams": "LAR",
    "Los Angeles Chargers": "LAC",
    "Miami Dolphins": "MD",
    "Minnesota Vikings": "MV",
    "New England Patriots": "NEP",
    "New Orleans Saints": "NOS",
    "New York Giants": "NYG",
    "New York Jets": "NYJ",
    "Philadelphia Eagles": "PE",
    "Pittsburgh Steelers": "PS",
    "San Francisco 49ers": "SF",
    "Seattle Seahawks": "SS",
    "Tampa Bay Buccaneers": "TBB",
    "Tennessee Titans": "TT",
    "Washington Commanders": "WC",
    "Washington Football Team": "WFT",
    "Washington Redskins": "WR",
    "Oakland Raiders": "OR",
    "San Diego Chargers": "SDC",
    "St. Louis Rams": "SLR",
}

mascot_encoded_teams = {
    "Cardinals": "AC",
    "Falcons": "AF",
    "Ravens": "BR",
    "Bills": "BB",
    "Panthers": "CP",
    "Bears": "CHB",
    "Bengals": "CNB",
    "Browns": "CLB",
    "Cowboys": "DC",
    "Broncos": "DB",
    "Lions": "DL",
    "Packers": "GBP",
    "Texans": "HT",
    "Colts": "IC",
    "Jaguars": "JJ",
    "Chiefs": "KC",
    "Raiders": "LVR",
    "Rams": "LAR",
    "Chargers": "LAC",
    "Dolphins": "MD",
    "Vikings": "MV",
    "Patriots": "NEP",
    "Saints": "NOS",
    "Giants": "NYG",
    "Jets": "NYJ",
    "Eagles": "PE",
    "Steelers": "PS",
    "Fortyniners": "SF",
    "Seahawks": "SS",
    "Buccaneers": "TBB",
    "Titans": "TT",
    "Commanders": "WC",
    "Washington Football Team": "WFT",
    "Washington Redskins": "WR",
    "Oakland": "OR",
    "San Diego Chargers": "SDC",
    "St. Louis Rams": "SLR",
}

url_decoded_teams = {
    "arizona-cardinals": "Arizona Cardinals",
    "atlanta-falcons": "Atlanta Falcons",
    "baltimore-ravens": "Baltimore Ravens",
    "buffalo-bills": "Buffalo Bills",
    "carolina-panthers": "Carolina Panthers",
    "chicago-bears": "Chicago Bears",
    "cincinnati-bengals": "Cincinnati Bengals",
    "cleveland-browns": "Cleveland Browns",
    "dallas-cowboys": "Dallas Cowboys",
    "denver-broncos": "Denver Broncos",
    "detroit-lions": "Detroit Lions",
    "green-bay-packers": "Green Bay Packers",
    "houston-texans": "Houston Texans",
    "indianapolis-colts": "Indianapolis Colts",
    "jacksonville-jaguars": "Jacksonville Jaguars",
    "kansas-city-chiefs": "Kansas City Chiefs",
    "las-vegas-raiders": "Las Vegas Raiders",
    "los-angeles-rams": "Los Angeles Rams",
    "los-angeles-chargers": "Los Angeles Chargers",
    "miami-dolphins": "Miami Dolphins",
    "minnesota-vikings": "Minnesota Vikings",
    "new-england-patriots": "New England Patriots",
    "new-orleans-saints": "New Orleans Saints",
    "new-york-giants": "New York Giants",
    "new-york-jets": "New York Jets",
    "philadelphia-eagles": "Philadelphia Eagles",
    "pittsburgh-steelers": "Pittsburgh Steelers",
    "san-francisco-49ers": "San Francisco 49ers",
    "seattle-seahawks": "Seattle Seahawks",
    "tampa-bay-buccaneers": "Tampa Bay Buccaneers",
    "tennessee-titans": "Tennessee Titans",
    "washington-commanders": "Washington Commanders",
    "washington-football-team": "Washington Football Team",
    "washington-redskins": "Washington Redskins",
    "oakland-raiders": "Oakland Raiders",
    "san-diego-chargers": "San Diego Chargers",
    "st-louis-rams": "St. Louis Rams",
}
